diff --git a/contrib/postgres_fdw/sql/postgres_fdw.sql b/contrib/postgres_fdw/sql/postgres_fdw.sql
index 8cb2148f1f..0c6bc240b7 100644
--- a/contrib/postgres_fdw/sql/postgres_fdw.sql
+++ b/contrib/postgres_fdw/sql/postgres_fdw.sql
@@ -3026,13 +3026,6 @@ SELECT COUNT(*) FROM ftable;
 TRUNCATE batch_table;
 DROP FOREIGN TABLE ftable;
 
--- try if large batches exceed max number of bind parameters
-CREATE FOREIGN TABLE ftable ( x int ) SERVER loopback OPTIONS ( table_name 'batch_table', batch_size '100000' );
-INSERT INTO ftable SELECT * FROM generate_series(1, 70000) i;
-SELECT COUNT(*) FROM ftable;
-TRUNCATE batch_table;
-DROP FOREIGN TABLE ftable;
-
 -- Disable batch insert
 CREATE FOREIGN TABLE ftable ( x int ) SERVER loopback OPTIONS ( table_name 'batch_table', batch_size '1' );
 EXPLAIN (VERBOSE, COSTS OFF) INSERT INTO ftable VALUES (1), (2);
@@ -3041,6 +3034,46 @@ SELECT COUNT(*) FROM ftable;
 DROP FOREIGN TABLE ftable;
 DROP TABLE batch_table;
 
+
+CREATE OR REPLACE FUNCTION create_batch_tables(p_cnt int) RETURNS void AS $$
+DECLARE
+    v_sql_local text := '';
+    v_sql_foreign text := '';
+    v_i int;
+BEGIN
+
+    v_sql_local := 'CREATE TABLE batch_table (';
+    v_sql_foreign := 'CREATE FOREIGN TABLE ftable (';
+
+    FOR v_i IN 1 .. p_cnt LOOP
+
+        IF v_i > 1 THEN
+            v_sql_local := v_sql_local || ', col_' || v_i || ' int';
+            v_sql_foreign := v_sql_foreign || ', col_' || v_i || ' int';
+        ELSE
+            v_sql_local := v_sql_local || 'col_' || v_i || ' int';
+            v_sql_foreign := v_sql_foreign || 'col_' || v_i || ' int';
+        END IF;
+
+    END LOOP;
+
+    v_sql_local := v_sql_local || ')';
+    v_sql_foreign := v_sql_foreign || ') SERVER loopback OPTIONS (table_name ''batch_table'', batch_size ''100000'' )';
+
+    EXECUTE v_sql_local;
+    EXECUTE v_sql_foreign;
+
+END;
+$$ LANGUAGE plpgsql;
+
+-- try if large batches exceed max number of bind parameters
+SELECT create_batch_tables(1500);
+INSERT INTO ftable SELECT * FROM generate_series(1, 50) i;
+SELECT COUNT(*) FROM ftable;
+DROP TABLE batch_table;
+DROP FOREIGN TABLE ftable;
+DROP FUNCTION create_batch_tables(int);
+
 -- Use partitioning
 CREATE TABLE batch_table ( x int ) PARTITION BY HASH (x);
 
